Class: Jekyll::FastReader::StopWords
- Inherits:
-
Object
- Object
- Jekyll::FastReader::StopWords
- Defined in:
- lib/jekyll/fast_reader/stop_words.rb
Constant Summary collapse
- DEFAULT =
Set.new(%w[ a an the of in on at to by or is as and but for nor so yet it its this that ]).freeze
Instance Method Summary collapse
-
#initialize(extra = []) ⇒ StopWords
constructor
A new instance of StopWords.
- #stop?(word) ⇒ Boolean
Constructor Details
Instance Method Details
#stop?(word) ⇒ Boolean
16 17 18 |
# File 'lib/jekyll/fast_reader/stop_words.rb', line 16 def stop?(word) @words.include?(word.downcase) end |